#![deny(missing_docs)]

//! A lending program for the Solana blockchain.

pub use crate::instruction::{
    deposit_obligation_collateral,
    redeem_reserve_collateral
};

mod instruction;
mod entrypoint;
mod error;
mod math;
mod processor;
mod pyth;
mod state;

// Export current sdk types for downstream users building with a different sdk version
pub use solana_program;

solana_program::declare_id!("TokenLending1111111111111111111111111111111");
